2022-01-05 Version: 3.0.5
- GetTemplate return value adds TemplateId, TemplateVersion, TemplateScratchId and TemplateURL.

2021-12-20 Version: 3.0.4
- CreateStack, PreviewStack and GetTemplateEstimateCost parameters supports specifing TemplateScratchRegionId.
- GetTemplateScratch return value adds StackProvision and UsageType in Stacks.
- GetTemplate return value adds ShareSource in Permissions.

2021-12-14 Version: 3.0.3
- Fix the issue that some parameters cannot be passed.

2021-12-07 Version: 3.0.2
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-30 Version: 3.0.1
- API GetStack supports Log for Terraform Stack.
- API GetChangeSet supports Log for Terraform Stack.
- API PreviewStack supports Log for Terraform Stack.

2021-11-22 Version: 3.0.0
- Add API GetServiceProvisions.
- Add API GetTemplateParameterConstraints.
- Add API GetFeatureDetails.
- CreateChangeSet supports Parallelism.

2021-09-23 Version: 2.1.3
- Terraform stack supports custom of parallelism.

2021-09-16 Version: 2.1.2
- Fixed the property AdministratorRoleName in GetStackGroupOperation  to AdministrationRoleName.

2021-09-03 Version: 2.1.1
- Fix type error of StackGroup and StackInstance parameters.

2021-09-03 Version: 2.1.0
- StackGroup supports specify resource folder to deploy StackInstances.
- StackGroup supports SERVICE_MANAGED and SELF_MANAGED permission models.

2021-08-27 Version: 2.0.6
- Support ClientToken for ValidateTemplate.

2021-07-20 Version: 2.0.5
- GetStack supports resource progress.
- ValidateTemplate supports Outputs.

2021-03-31 Version: 2.0.4
- Generated python 2019-09-10 for ROS.

2021-01-22 Version: 2.0.3
- Generated python 2019-09-10 for ROS.

2021-01-22 Version: 1.3.0
- Generated python 2019-09-10 for ROS.

2021-01-21 Version: 1.2.2
- Generated python 2019-09-10 for ROS.

2021-01-21 Version: 1.2.1
- The creation and update APIs of the stack supports specifing tags, and the query and list APIs supports obtaining tags.

2021-01-20 Version: 2.0.2
- AMP Version Change.

2021-01-20 Version: 2.0.1
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-30 Version: 2.0.0
- AMP Version Change.

2020-12-17 Version: 1.2.0
- Support template version.
- Support to share template.
- Stack and StackGroup support TemplateId and TemplateVersion.
- Add GenerateTemplatePolicy which can generate RAM policy by template.

